@@ -22,11 +22,11 @@ DBIx::Class::Test::SQLite - Base class for running Class::DBI tests against DBIx
 	
 =head1 DESCRIPTION
 
-This provides a simple base class for DBIx::Class::CDBICompat tests using
-SQLite.  Each class for the test should inherit from this, provide a
-create_sql() method which returns a string representing the SQL used to
-create the table for the class, and then call set_table() to create the
-table, and tie it to the class.
+This provides a simple base class for DBIx::Class tests using SQLite.
+Each class for the test should inherit from this, provide a create_sql()
+method which returns a string representing the SQL used to create the
+table for the class, and then call set_table() to create the table, and
+tie it to the class.
 
 =cut
 
@@ -34,7 +34,7 @@ use strict;
 
 use base qw/DBIx::Class/;
 
-__PACKAGE__->load_components(qw/PK::Auto::SQLite CDBICompat Core DB/);
+__PACKAGE__->load_components(qw/CDBICompat PK::Auto::SQLite Core DB/);
 
 use File::Temp qw/tempfile/;
 my (undef, $DB) = tempfile();
@@ -45,7 +45,6 @@ my @DSN = ("dbi:SQLite:dbname=$DB", '', '', { AutoCommit => 1, RaiseError => 1 }
 __PACKAGE__->connection(@DSN);
 __PACKAGE__->set_sql(_table_pragma => 'PRAGMA table_info(__TABLE__)');
 __PACKAGE__->set_sql(_create_me    => 'CREATE TABLE __TABLE__ (%s)');
-__PACKAGE__->storage->dbh->do("PRAGMA synchronous = OFF");
 
 =head1 METHODS
 
@@ -68,11 +67,14 @@ sub _create_test_table {
 	my $class = shift;
         my @vals  = $class->sql__table_pragma->select_row;
         $class->sql__create_me($class->create_sql)->execute unless @vals;
+#	my @vals  = $class->_sql_to_sth(
+#                      'PRAGMA table_info(__TABLE__)')->select_row;
+#	$class->_sql_to_sth(
+#          'CREATE TABLE '.$class->table.' ('.$class->create_sql.')'
+#            )->execute unless @vals;
 }
 
-=head2 create_sql
-
-This is an abstract method you must override.
+=head2 create_sql (abstract)
 
 	sub create_sql { 
 		return q{
